@@ -259,7 +259,6 @@ class Classification:
         if self.predictor == 'all':
             self.pred_mode = 'all'
             self._fitall()
-            return
             
         elif self.predictor == 'ann':
             self.parameters, self.classifier, self.classifier_wrap = classificationPredictor(
@@ -394,7 +393,7 @@ class Classification:
         print('Complete [', u'\u2713', ']\n')
         self.end = time.time()
         print('Time Elapsed : ', self.end - self.start, 'seconds \n')
-        
+        return
 
     def __tuner(self, all_mode=False):
         if not all_mode:
@@ -419,7 +418,7 @@ class Classification:
                         - "Accuracy" - KFold CV Accuracy
                         - "YPred" - Array for Prediction set
                         ]
-            [pd.dataframe] : [Dataset containing accuracy and best_params 
+            [dataframe] : [Dataset containing accuracy and best_params 
                             for all predictors only when predictor = 'all' is used
                             ]
         """
